"""
This module exports the base exceptions used in all :mod:`royalnet` modules.
"""


class RoyalnetException(Exception):
    """An exception raised by a Royalnet module."""


__all__ = ("RoyalnetException",)
